{ config, pkgs, inputs, ... }:
{
  imports = [
    ./../common
    ./../modules/hyprland
  ];
  /* The home.stateVersion option does not have a default and must be set */
  home.stateVersion = "24.11";
  home.username = "leonv";
  home.homeDirectory = "/home/leonv";

  modules.hyprland = {
    enable = true;
    hyprpaper = {
      enable = true;
      wallpaper = ./wallpaper.jpg;
    };
    monitor = [
      "DP-1    , 2560x1440@144, 1920x0, 1"
      "HDMI-A-1, 1920x1080@75 , 0x0   , 1"
    ];
    workspace = [
      "1, monitor:HDMI-A-1,  default:true, persistent:true"
      "2, monitor:DP-1    ,  default:true, persistent:true"
      "special:scratchpad ,  on-created-empty:foot"
    ];
  };

  home.packages = with pkgs; [ 
    # operating systems stuff / C/C++
    grub2
    xorriso
    qemu
    nasm
    man-pages
    man-pages-posix
    cpplint
    gcc
    gdb
    gnumake

    # prolog
    swi-prolog

    # go
    go

    # java
    jetbrains.idea-ultimate
    jdk11

    # haskell
    doxygen
    haskell.compiler.ghc981
    cabal-install
    haskell-language-server

    # script
    ghostscript
    python3
    python3Packages.pygments

    # proof assistants
    unifont
    (agda.withPackages [ 
      agdaPackages.standard-library
      agdaPackages.agda-categories
    ])
    coq
    lean4

    # for emacs
    texlab
    shellcheck
    emacs
  ];

  # emacs
  xdg.configHome = /home/leonv/.config;
  xdg.configFile."doom/init.el".source = ./doom/init.el;
  xdg.configFile."doom/config.el".source = ./doom/config.el;
  xdg.configFile."doom/packages.el".source = ./doom/packages.el;
  home.sessionPath = [ "$HOME/.config/emacs/bin" ];

  programs.home-manager.enable = true;

  # for bluetooth headset functionality
  services.mpris-proxy.enable = true;
}
